==> dokuwiki-2016.06.26a.tgz: dokuwiki/lib/plugins/extension/lang/it/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Francesco <francesco.cavalli@hotmail.com>
 * @author Fabio <fabioslurp@yahoo.it>
 * @author Torpedo <dgtorpedo@gmail.com>
 * @author Maurizio <mcannavo@katamail.com>
 */
$lang['menu']                  = 'Manager delle Extension';
$lang['tab_plugins']           = 'Plugin Installati';
$lang['tab_templates']         = 'Template Installati';
$lang['tab_search']            = 'Ricerca e Installazione';
$lang['tab_install']           = 'Installazione Manuale';
$lang['notimplemented']        = 'Questa funzionalità non è ancora stata implementata';
$lang['notinstalled']          = 'Questa extension non è installata';
$lang['alreadyenabled']        = 'Questa extension è già stata abilitata';
$lang['alreadydisabled']       = 'Questa extension à già stata disabilitata';
$lang['pluginlistsaveerror']   = 'Si è verificato un errore durante il salvataggio dell\'elenco dei plugin';
$lang['unknownauthor']         = 'Autore sconosciuto';
$lang['unknownversion']        = 'Revisione sconosciuta';
$lang['btn_info']              = 'Mostra maggiori informazioni';
$lang['btn_update']            = 'Aggiorna';
$lang['btn_uninstall']         = 'Disinstalla';
$lang['btn_enable']            = 'Abilita';
$lang['btn_disable']           = 'Disabilita';
$lang['btn_install']           = 'Installa';
$lang['btn_reinstall']         = 'Reinstalla';
$lang['js']['reallydel']       = 'Sicuro di disinstallare questa estensione?';
$lang['js']['display_viewoptions'] = 'Opzioni di Visualizzazione:';
$lang['js']['display_enabled'] = 'abilitato';
$lang['js']['display_disabled'] = 'disabilitato';
$lang['js']['display_updatable'] = 'aggiornabile';
$lang['search_for']            = 'Extension di Ricerca:';
$lang['search']                = 'Cerca';
$lang['extensionby']           = '<strong>%s</strong> da %s';
$lang['screenshot']            = 'Screenshot di %s';
$lang['popularity']            = 'Popolarità: %s%%';
$lang['homepage_link']         = 'Documenti';
$lang['bugs_features']         = 'Bug';
$lang['tags']                  = 'Tag:';
$lang['author_hint']           = 'Cerca estensioni per questo autore';
$lang['installed']             = 'Installato:';
$lang['downloadurl']           = 'URL download:';
$lang['repository']            = 'Repository';
$lang['unknown']               = '<em>sconosciuto</em>';
$lang['installed_version']     = 'Versione installata';
$lang['install_date']          = 'Il tuo ultimo aggiornamento:';
$lang['available_version']     = 'Versione disponibile:';
$lang['compatible']            = 'Compatibile con:';
$lang['depends']               = 'Dipende da:';
$lang['similar']               = 'Simile a:';
$lang['conflicts']             = 'Conflitto con:';
$lang['donate']                = 'Simile a questo?';
$lang['donate_action']         = 'Paga un caffè all\'autore!';
$lang['repo_retry']            = 'Riprova';
$lang['provides']              = 'Fornisce:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'installato';
$lang['status_not_installed']  = 'non installato';
$lang['status_protected']      = 'protetto';
$lang['status_enabled']        = 'abilitato';
$lang['status_disabled']       = 'disabilitato';
$lang['status_unmodifiable']   = 'inmodificabile';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'modello';
$lang['status_bundled']        = 'accoppiato';
$lang['msg_enabled']           = 'Plugin %s abilitato';
$lang['msg_disabled']          = 'Plugin %s disabilitato';
$lang['msg_delete_success']    = 'Estensione %s disinstallata';
$lang['msg_delete_failed']     = 'Disinstallazione dell\'Extension %s fallita';
$lang['msg_template_install_success'] = 'Il template %s è stato installato correttamente';
$lang['msg_template_update_success'] = 'Il Template %s è stato aggiornato correttamente';
$lang['msg_plugin_install_success'] = 'Plugin %s installato con successo';
$lang['msg_plugin_update_success'] = 'Plugin %s aggiornato con successo';
$lang['msg_upload_failed']     = 'Caricamento del file fallito';
$lang['missing_dependency']    = '<strong>Dipendenza mancante o disabilitata: </strong> %s';
$lang['security_issue']        = '<strong>Problema di sicurezza:</strong> %s';
$lang['security_warning']      = '<strong>Avvertimento di sicurezza:</strong> %s';
$lang['update_available']      = '<strong>Aggiornamento:</strong> Nuova versione %s disponibile.';
$lang['wrong_folder']          = '<strong>Plugin non installato correttamente:</strong> rinomina la directory del plugin "%s" in "%s".';
$lang['url_change']            = '<strong>URL cambiato:</strong> l\'URL per il download è cambiato dall\'ultima volta che è stato utilizzato. Controlla se il nuovo URL è valido prima di aggiornare l\'estensione.<br />Nuovo: %s<br />Vecchio: %s';
$lang['error_badurl']          = 'URLs deve iniziare con http o https';
$lang['error_dircreate']       = 'Impossibile creare una cartella temporanea per ricevere il download';
$lang['error_download']        = 'Impossibile scaricare il file: %s';
$lang['error_decompress']      = 'Impossibile decomprimere il file scaricato. Ciò può dipendere da errori in fase di download, nel qual caso dovreste ripetere l\'operazione; oppure il formato di compressione è sconosciuto, e in questo caso dovrete scaricare e installare manualmente.';
$lang['error_findfolder']      = 'Impossibile identificare la directory dell\'extension, dovrete scaricare e installare manualmente';
$lang['error_copy']            = 'C\'è stato un errore di copia dei file mentre si tentava di copiare i file per la directory <em>%s</em>: il disco potrebbe essere pieno o i pemessi di accesso ai file potrebbero essere sbagliati. Questo potrebbe aver causato una parziale installazione dei plugin lasciando il tuo wiki instabile';
$lang['noperms']               = 'La directory Extension non è scrivibile';
$lang['notplperms']            = 'Il modello di cartella non è scrivibile';
$lang['nopluginperms']         = 'La cartella plugin non è scrivibile';
$lang['git']                   = 'Questa extension è stata installata da git, potreste non volerla aggiornare qui.';
$lang['auth']                  = 'Questo plugin di autenticazione non è abilitato nella configurazione, considera di disabilitarlo.';
$lang['install_url']           = 'Installa da URL:';
$lang['install_upload']        = 'Caricamento Extension:';
$lang['repo_error']            = 'Il repository dei plugin non può essere raggiunto. Assicuratevi che il vostro server sia abilitato a contattare l\'indirizzo www.dokuwiki.org e controllate le impostazioni del vostro proxy.';
$lang['nossl']                 = 'La tua installazione PHP sembra mancare del supporto SSL. I download per molte estensioni di DokuWiki non funzioneranno.';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/extension/lang/it/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Filippo <abrickslife@gmail.com>
 * @author Francesco <francesco.cavalli@hotmail.com>
 * @author Fabio <fabioslurp@yahoo.it>
 * @author Torpedo <dgtorpedo@gmail.com>
 * @author Maurizio <mcannavo@katamail.com>
 */
$lang['menu']                  = 'Manager delle Extension';
$lang['tab_plugins']           = 'Plugin Installati';
$lang['tab_templates']         = 'Template Installati';
$lang['tab_search']            = 'Ricerca e Installazione';
$lang['tab_install']           = 'Installazione Manuale';
$lang['notimplemented']        = 'Questa funzionalità non è ancora stata implementata';
$lang['notinstalled']          = 'Questa extension non è installata';
$lang['alreadyenabled']        = 'Questa extension è già stata abilitata';
$lang['alreadydisabled']       = 'Questa extension à già stata disabilitata';
$lang['pluginlistsaveerror']   = 'Si è verificato un errore durante il salvataggio dell\'elenco dei plugin';
$lang['unknownauthor']         = 'Autore sconosciuto';
$lang['unknownversion']        = 'Revisione sconosciuta';
$lang['btn_info']              = 'Mostra maggiori informazioni';
$lang['btn_update']            = 'Aggiorna';
$lang['btn_uninstall']         = 'Disinstalla';
$lang['btn_enable']            = 'Abilita';
$lang['btn_disable']           = 'Disabilita';
$lang['btn_install']           = 'Installa';
$lang['btn_reinstall']         = 'Reinstalla';
$lang['js']['reallydel']       = 'Sicuro di disinstallare questa estensione?';
$lang['js']['display_viewoptions'] = 'Opzioni di Visualizzazione:';
$lang['js']['display_enabled'] = 'abilitato';
$lang['js']['display_disabled'] = 'disabilitato';
$lang['js']['display_updatable'] = 'aggiornabile';
$lang['search_for']            = 'Extension di Ricerca:';
$lang['search']                = 'Cerca';
$lang['extensionby']           = '<strong>%s</strong> da %s';
$lang['screenshot']            = 'Screenshot di %s';
$lang['popularity']            = 'Popolarità: %s%%';
$lang['homepage_link']         = 'Documenti';
$lang['bugs_features']         = 'Bug';
$lang['tags']                  = 'Tag:';
$lang['author_hint']           = 'Cerca estensioni per questo autore';
$lang['installed']             = 'Installato:';
$lang['downloadurl']           = 'URL download:';
$lang['repository']            = 'Repository';
$lang['unknown']               = '<em>sconosciuto</em>';
$lang['installed_version']     = 'Versione installata';
$lang['install_date']          = 'Il tuo ultimo aggiornamento:';
$lang['available_version']     = 'Versione disponibile:';
$lang['compatible']            = 'Compatibile con:';
$lang['depends']               = 'Dipende da:';
$lang['similar']               = 'Simile a:';
$lang['conflicts']             = 'Conflitto con:';
$lang['donate']                = 'Simile a questo?';
$lang['donate_action']         = 'Paga un caffè all\'autore!';
$lang['repo_retry']            = 'Riprova';
$lang['provides']              = 'Fornisce:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'installato';
$lang['status_not_installed']  = 'non installato';
$lang['status_protected']      = 'protetto';
$lang['status_enabled']        = 'abilitato';
$lang['status_disabled']       = 'disabilitato';
$lang['status_unmodifiable']   = 'inmodificabile';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'modello';
$lang['status_bundled']        = 'accoppiato';
$lang['msg_enabled']           = 'Plugin %s abilitato';
$lang['msg_disabled']          = 'Plugin %s disabilitato';
$lang['msg_delete_success']    = 'Estensione %s disinstallata';
$lang['msg_delete_failed']     = 'Disinstallazione dell\'Extension %s fallita';
$lang['msg_template_install_success'] = 'Il template %s è stato installato correttamente';
$lang['msg_template_update_success'] = 'Il Template %s è stato aggiornato correttamente';
$lang['msg_plugin_install_success'] = 'Plugin %s installato con successo';
$lang['msg_plugin_update_success'] = 'Plugin %s aggiornato con successo';
$lang['msg_upload_failed']     = 'Caricamento del file fallito';
$lang['msg_nooverwrite']       = 'L\'estensione %s esiste già e non è stata sovrascritta; per sovrascriverla, seleziona l\'opzione "overwrite" o "sovrascrivi"';
$lang['missing_dependency']    = '<strong>Dipendenza mancante o disabilitata: </strong> %s';
$lang['security_issue']        = '<strong>Problema di sicurezza:</strong> %s';
$lang['security_warning']      = '<strong>Avvertimento di sicurezza:</strong> %s';
$lang['update_available']      = '<strong>Aggiornamento:</strong> Nuova versione %s disponibile.';
$lang['wrong_folder']          = '<strong>Plugin non installato correttamente:</strong> rinomina la directory del plugin "%s" in "%s".';
$lang['url_change']            = '<strong>URL cambiato:</strong> l\'URL per il download è cambiato dall\'ultima volta che è stato utilizzato. Controlla se il nuovo URL è valido prima di aggiornare l\'estensione.<br />Nuovo: %s<br />Vecchio: %s';
$lang['error_badurl']          = 'URLs deve iniziare con http o https';
$lang['error_dircreate']       = 'Impossibile creare una cartella temporanea per ricevere il download';
$lang['error_download']        = 'Impossibile scaricare il file: %s';
$lang['error_decompress']      = 'Impossibile decomprimere il file scaricato. Ciò può dipendere da errori in fase di download, nel qual caso dovreste ripetere l\'operazione; oppure il formato di compressione è sconosciuto, e in questo caso dovrete scaricare e installare manualmente.';
$lang['error_findfolder']      = 'Impossibile identificare la directory dell\'extension, dovrete scaricare e installare manualmente';
$lang['error_copy']            = 'C\'è stato un errore di copia dei file mentre si tentava di copiare i file per la directory <em>%s</em>: il disco potrebbe essere pieno o i pemessi di accesso ai file potrebbero essere sbagliati. Questo potrebbe aver causato una parziale installazione dei plugin lasciando il tuo wiki instabile';
$lang['noperms']               = 'La directory Extension non è scrivibile';
$lang['notplperms']            = 'Il modello di cartella non è scrivibile';
$lang['nopluginperms']         = 'La cartella plugin non è scrivibile';
$lang['git']                   = 'Questa extension è stata installata da git, potreste non volerla aggiornare qui.';
$lang['auth']                  = 'Questo plugin di autenticazione non è abilitato nella configurazione, considera di disabilitarlo.';
$lang['install_url']           = 'Installa da URL:';
$lang['install_upload']        = 'Caricamento Extension:';
$lang['repo_error']            = 'Il repository dei plugin non può essere raggiunto. Assicuratevi che il vostro server sia abilitato a contattare l\'indirizzo www.dokuwiki.org e controllate le impostazioni del vostro proxy.';
$lang['nossl']                 = 'La tua installazione PHP sembra mancare del supporto SSL. I download per molte estensioni di DokuWiki non funzioneranno.';
